Block parsing utilities.
Uses chia_consensus to extract additions, removals, and coin spends from
a FullBlock’s CLVM generator. Follows the same patterns as the
chia-block-listener / chia-generator-parser crates.
Functions
- block_
additions_ and_ removals - Extract coin additions and removals from a full block’s generator.
- block_
spends - Run the block generator and extract all coin spends with their puzzle_reveal and solution.
- block_
spends_ with_ conditions - Same as
block_spendsbut also runs each puzzle against its solution to extract the CLVM output conditions. - parse_
conditions_ public - Public version of condition parsing for use from
router.rs.