pub struct QueryRouter { /* private fields */ }Implementations
Sourceimpl QueryRouter
impl QueryRouter
Sourcepub async fn get_additions_and_removals(
&self,
header_hash: &str,
) -> Result<AdditionsAndRemovals, ChiaQueryError>
pub async fn get_additions_and_removals( &self, header_hash: &str, ) -> Result<AdditionsAndRemovals, ChiaQueryError>
Peer-backed: fetches the full block by header_hash (via coinset to resolve the height), then parses additions/removals from the CLVM generator. Falls back to the coinset endpoint on failure.
pub async fn get_block( &self, header_hash: &str, ) -> Result<FullBlock, ChiaQueryError>
Sourcepub async fn get_block_by_height(
&self,
height: u32,
) -> Result<FullBlock, ChiaQueryError>
pub async fn get_block_by_height( &self, height: u32, ) -> Result<FullBlock, ChiaQueryError>
Fetch a full block by height. Peer-backed via RequestBlock.
pub async fn get_block_count_metrics( &self, ) -> Result<BlockCountMetrics, ChiaQueryError>
pub async fn get_block_record( &self, header_hash: &str, ) -> Result<BlockRecord, ChiaQueryError>
Sourcepub async fn get_block_record_by_height(
&self,
height: u32,
) -> Result<BlockRecord, ChiaQueryError>
pub async fn get_block_record_by_height( &self, height: u32, ) -> Result<BlockRecord, ChiaQueryError>
Peer-backed via RequestBlockHeader / RespondBlockHeader (pattern
from chia-block-listener).
pub async fn get_block_records( &self, start: u32, end: u32, ) -> Result<Vec<BlockRecord>, ChiaQueryError>
Sourcepub async fn get_block_spends(
&self,
header_hash: &str,
) -> Result<Vec<CoinSpend>, ChiaQueryError>
pub async fn get_block_spends( &self, header_hash: &str, ) -> Result<Vec<CoinSpend>, ChiaQueryError>
Peer-backed: fetches the full block, then runs the CLVM generator to extract every coin spend with its puzzle_reveal and solution.
Sourcepub async fn get_block_spends_with_conditions(
&self,
header_hash: &str,
) -> Result<Vec<CoinSpendWithConditions>, ChiaQueryError>
pub async fn get_block_spends_with_conditions( &self, header_hash: &str, ) -> Result<Vec<CoinSpendWithConditions>, ChiaQueryError>
Peer-backed: fetches full block, runs CLVM generator, then runs each puzzle(solution) to extract parsed conditions.
pub async fn get_blocks( &self, start: u32, end: u32, exclude_header_hash: bool, exclude_reorged: bool, ) -> Result<Vec<FullBlock>, ChiaQueryError>
pub async fn get_unfinished_block_headers( &self, ) -> Result<Vec<UnfinishedBlockHeader>, ChiaQueryError>
Sourceimpl QueryRouter
impl QueryRouter
pub async fn get_coin_record_by_name( &self, name: &str, ) -> Result<CoinRecord, ChiaQueryError>
pub async fn get_coin_records_by_hint( &self, hint: &str, start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_hints( &self, hints: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_names( &self, names: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
Sourcepub async fn get_coin_records_by_parent_ids(
&self,
parent_ids: &[String],
start_height: Option<u32>,
end_height: Option<u32>,
include_spent_coins: bool,
) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_parent_ids( &self, parent_ids: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
Peer-backed via RequestChildren / RespondChildren which returns
child coin states for a given parent coin ID. Falls back to coinset
for batched queries or when peers fail.
pub async fn get_coin_records_by_puzzle_hash( &self, puzzle_hash: &str, start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_puzzle_hashes( &self, puzzle_hashes: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
Sourcepub async fn get_memos_by_coin_name(
&self,
name: &str,
) -> Result<Value, ChiaQueryError>
pub async fn get_memos_by_coin_name( &self, name: &str, ) -> Result<Value, ChiaQueryError>
No peer equivalent – always coinset.
pub async fn get_puzzle_and_solution( &self, coin_id: &str, height: Option<u32>, ) -> Result<CoinSpend, ChiaQueryError>
Sourcepub async fn get_puzzle_and_solution_with_conditions(
&self,
coin_id: &str,
height: Option<u32>,
) -> Result<CoinSpendWithConditions, ChiaQueryError>
pub async fn get_puzzle_and_solution_with_conditions( &self, coin_id: &str, height: Option<u32>, ) -> Result<CoinSpendWithConditions, ChiaQueryError>
Peer-backed: get puzzle & solution, then run puzzle(solution) to extract parsed conditions.
pub async fn push_tx( &self, bundle: &SpendBundle, ) -> Result<TxStatus, ChiaQueryError>
Sourceimpl QueryRouter
impl QueryRouter
pub async fn get_fee_estimate( &self, spend_bundle: Option<&SpendBundle>, target_times: Option<&[u64]>, spend_count: Option<u64>, ) -> Result<FeeEstimate, ChiaQueryError>
Sourceimpl QueryRouter
impl QueryRouter
Sourcepub async fn get_aggsig_additional_data(&self) -> Result<String, ChiaQueryError>
pub async fn get_aggsig_additional_data(&self) -> Result<String, ChiaQueryError>
Peer-backed: derived from the chia consensus constants for the configured network.
Sourcepub async fn get_network_info(&self) -> Result<NetworkInfo, ChiaQueryError>
pub async fn get_network_info(&self) -> Result<NetworkInfo, ChiaQueryError>
Peer-backed: derived from the chia consensus constants for the configured network.
Sourcepub async fn get_blockchain_state(
&self,
) -> Result<BlockchainState, ChiaQueryError>
pub async fn get_blockchain_state( &self, ) -> Result<BlockchainState, ChiaQueryError>
Peer-backed partially: peak height is tracked from NewPeakWallet
messages received from peers. Full state comes from coinset.
pub async fn get_network_space( &self, newer_block_header_hash: &str, older_block_header_hash: &str, ) -> Result<u64, ChiaQueryError>
Sourceimpl QueryRouter
impl QueryRouter
pub async fn get_all_mempool_items( &self, ) -> Result<HashMap<String, MempoolItem>, ChiaQueryError>
pub async fn get_all_mempool_tx_ids( &self, ) -> Result<Vec<String>, ChiaQueryError>
pub async fn get_mempool_item_by_tx_id( &self, tx_id: &str, ) -> Result<MempoolItem, ChiaQueryError>
pub async fn get_mempool_items_by_coin_name( &self, coin_name: &str, include_spent_coins: Option<bool>, ) -> Result<Vec<MempoolItem>, ChiaQueryError>