pub struct ChiaQuery { /* private fields */ }Implementations
Sourceimpl ChiaQuery
impl ChiaQuery
Sourcepub async fn new(cfg: ChiaQueryConfig) -> Result<Self, ChiaQueryError>
pub async fn new(cfg: ChiaQueryConfig) -> Result<Self, ChiaQueryError>
Create a new client. This will:
- Load TLS certificates from the configured paths.
- Discover peers via DNS and connect up to
max_peersconcurrently. - Initialise the coinset.org HTTP client.
At least one peer must connect successfully, otherwise this returns
ChiaQueryError::PeerDiscoveryFailed.
pub async fn get_additions_and_removals( &self, header_hash: &str, ) -> Result<AdditionsAndRemovals, ChiaQueryError>
pub async fn get_block( &self, header_hash: &str, ) -> Result<FullBlock, ChiaQueryError>
Sourcepub async fn get_block_by_height(
&self,
height: u32,
) -> Result<FullBlock, ChiaQueryError>
pub async fn get_block_by_height( &self, height: u32, ) -> Result<FullBlock, ChiaQueryError>
Fetch a full block by height. Peer-backed via RequestBlock.
pub async fn get_block_count_metrics( &self, ) -> Result<BlockCountMetrics, ChiaQueryError>
pub async fn get_block_record( &self, header_hash: &str, ) -> Result<BlockRecord, ChiaQueryError>
pub async fn get_block_record_by_height( &self, height: u32, ) -> Result<BlockRecord, ChiaQueryError>
pub async fn get_block_records( &self, start: u32, end: u32, ) -> Result<Vec<BlockRecord>, ChiaQueryError>
pub async fn get_block_spends( &self, header_hash: &str, ) -> Result<Vec<CoinSpend>, ChiaQueryError>
pub async fn get_block_spends_with_conditions( &self, header_hash: &str, ) -> Result<Vec<CoinSpendWithConditions>, ChiaQueryError>
pub async fn get_blocks( &self, start: u32, end: u32, exclude_header_hash: bool, exclude_reorged: bool, ) -> Result<Vec<FullBlock>, ChiaQueryError>
pub async fn get_unfinished_block_headers( &self, ) -> Result<Vec<UnfinishedBlockHeader>, ChiaQueryError>
pub async fn get_coin_record_by_name( &self, name: &str, ) -> Result<CoinRecord, ChiaQueryError>
pub async fn get_coin_records_by_hint( &self, hint: &str, start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_hints( &self, hints: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_names( &self, names: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_parent_ids( &self, parent_ids: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_puzzle_hash( &self, puzzle_hash: &str, start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_coin_records_by_puzzle_hashes( &self, puzzle_hashes: &[String], start_height: Option<u32>, end_height: Option<u32>, include_spent_coins: bool, ) -> Result<Vec<CoinRecord>, ChiaQueryError>
pub async fn get_memos_by_coin_name( &self, name: &str, ) -> Result<Value, ChiaQueryError>
pub async fn get_puzzle_and_solution( &self, coin_id: &str, height: Option<u32>, ) -> Result<CoinSpend, ChiaQueryError>
pub async fn get_puzzle_and_solution_with_conditions( &self, coin_id: &str, height: Option<u32>, ) -> Result<CoinSpendWithConditions, ChiaQueryError>
pub async fn push_tx( &self, spend_bundle: &SpendBundle, ) -> Result<TxStatus, ChiaQueryError>
pub async fn get_fee_estimate( &self, spend_bundle: Option<&SpendBundle>, target_times: Option<&[u64]>, spend_count: Option<u64>, ) -> Result<FeeEstimate, ChiaQueryError>
pub async fn get_aggsig_additional_data(&self) -> Result<String, ChiaQueryError>
pub async fn get_network_info(&self) -> Result<NetworkInfo, ChiaQueryError>
pub async fn get_blockchain_state( &self, ) -> Result<BlockchainState, ChiaQueryError>
pub async fn get_network_space( &self, newer_block_header_hash: &str, older_block_header_hash: &str, ) -> Result<u64, ChiaQueryError>
pub async fn get_all_mempool_items( &self, ) -> Result<HashMap<String, MempoolItem>, ChiaQueryError>
pub async fn get_all_mempool_tx_ids( &self, ) -> Result<Vec<String>, ChiaQueryError>
pub async fn get_mempool_item_by_tx_id( &self, tx_id: &str, ) -> Result<MempoolItem, ChiaQueryError>
pub async fn get_mempool_items_by_coin_name( &self, coin_name: &str, include_spent_coins: Option<bool>, ) -> Result<Vec<MempoolItem>, ChiaQueryError>
Sourcepub async fn wait_for_confirmation(
&self,
coin_id: &str,
poll_interval: Duration,
timeout: Duration,
) -> Result<CoinRecord, ChiaQueryError>
pub async fn wait_for_confirmation( &self, coin_id: &str, poll_interval: Duration, timeout: Duration, ) -> Result<CoinRecord, ChiaQueryError>
Poll the blockchain until a coin appears on-chain (confirmed) or the timeout elapses.
Returns the CoinRecord once the coin is found with a non-zero
confirmed_block_index. Returns an error if the timeout expires
before the coin is confirmed.
let client = ChiaQuery::new(ChiaQueryConfig::default()).await?;
let record = client.wait_for_confirmation(
"0xabc...",
Duration::from_secs(5), // poll every 5 seconds
Duration::from_secs(300), // give up after 5 minutes
).await?;
println!("confirmed at height {}", record.confirmed_block_index);Auto Trait Implementations
impl !Freeze for ChiaQuery
impl !RefUnwindSafe for ChiaQuery
impl Send for ChiaQuery
impl Sync for ChiaQuery
impl Unpin for ChiaQuery
impl UnsafeUnpin for ChiaQuery
impl !UnwindSafe for ChiaQuery